@@ -1,21 +1,34 @@
 from datetime import datetime, timedelta
-from typing import Any, Dict, List
+from typing import Any, Dict, List, NoReturn
 
 from gcal_notifier.utils import CMD, run_notify
 
 
 class SimpleGCalendarNotifier:
+    """Notifier for GoogleCalendar events.
+
+    Args:
+        events (List[Dict[str, Any]]): List of all cached events
+        general_params (Dict[str, Any]): General params
+        calendar_params (Dict[str, Any]): Calendar params
+
+    Attributes:
+        events (List[Dict[str, Any]]): List of all events
+    """
+
+    events: List[Dict[str, Any]]
 
     def __init__(
         self,
         events: List[Dict[str, Any]],
         general_params: Dict[str, Any],
         calendar_params: Dict[str, Any],
-    ):
+    ) -> NoReturn:
         self.events = events
         self.search_reminders()
 
-    def search_reminders(self):
+    def search_reminders(self) -> NoReturn:
+        """Search current reminders to notify."""
         now = datetime.now().astimezone()
         for event in self.events:
             start = event["start"]
@@ -31,7 +44,13 @@ class SimpleGCalendarNotifier:
                     run_notify(cmd)
 
     @staticmethod
-    def create_command(event: Dict[str, Any], cmd: str = CMD):
+    def create_command(event: Dict[str, Any], cmd: str = CMD) -> str:
+        """Create a notify command formatting a cmd string.
+
+        Args:
+            event (Dict[str, Any]): Event info
+            cmd (str): Base command to format
+        """
         formatters = {
             "title": f'"{event.get("summary", None)}"',
             "calendar": f'"{event.get("calendar", None)}"',
